==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/bd/bd6f9296c9cf789f7f15e5c2b5489f1d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Crate/FieldCrate.php */
class __TwigTemplate_d8084aef72e0e309de9d39edddb454a6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Crate;

use Mautic\\LeadBundle\\Helper\\FormFieldHelper;

final class FieldCrate
{
    /**
     * @param mixed[] \$properties
     */
    public function __construct(
        private string \$key,
        private string \$name,
        private string \$type,
        private array \$properties
    ) {
    }

    public function getKey(): string
    {
        return \$this->key;
    }

    public function getName(): string
    {
        return \$this->name;
    }

    public function getType(): string
    {
        return \$this->type;
    }

    /**
     * @return mixed[]
     */
    public function getProperties(): array
    {
        return \$this->properties;
    }

    public function isListType(): bool
    {
        \$isListType    = in_array(\$this->getType(), FormFieldHelper::getListTypes());
        \$hasList       = !empty(\$this->getProperties()['list']);
        \$hasOptionList = !empty(\$this->getProperties()['optionlist']);

        return \$isListType || \$hasList || \$hasOptionList;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Crate/FieldCrate.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Crate/FieldCrate.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Crate/FieldCrate.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/bd/bd6f9296c9cf789f7f15e5c2b5489f1d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Crate/FieldCrate.php */
class __TwigTemplate_d8084aef72e0e309de9d39edddb454a6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Crate;

use Mautic\\LeadBundle\\Helper\\FormFieldHelper;

final class FieldCrate
{
    /**
     * @param mixed[] \$properties
     */
    public function __construct(
        private string \$key,
        private string \$name,
        private string \$type,
        private array \$properties
    ) {
    }

    public function getKey(): string
    {
        return \$this->key;
    }

    public function getName(): string
    {
        return \$this->name;
    }

    public function getType(): string
    {
        return \$this->type;
    }

    /**
     * @return mixed[]
     */
    public function getProperties(): array
    {
        return \$this->properties;
    }

    public function isListType(): bool
    {
        \$isListType    = in_array(\$this->getType(), FormFieldHelper::getListTypes());
        \$hasList       = !empty(\$this->getProperties()['list']);
        \$hasOptionList = !empty(\$this->getProperties()['optionlist']);

        return \$isListType || \$hasList || \$hasOptionList;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Crate/FieldCrate.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Crate/FieldCrate.php", "/var/www/html/production-demo/app/bundles/FormBundle/Crate/FieldCrate.php");
    }
}
